# Clean the environement
rm(list = ls())

# To execute the selected line(s):
# ctrl + enter
# or Click "run"

# To load packages (these need to be installed beforehand)
# (make its objects available without prefixing
# with the "packagename::objectname" syntax)
library(tableone)
library(ggplot2)
library(officer)
library(openxlsx)


# Set source file directory
# (the goal is to be able to find the input table,
# and to output the results in the correct place)
# In RStudio: Session / Set Working Directory / To Source File Location
# Replace with the correct value for you
# setwd("~/Documents/Cours/Analyse_donnees_Pasteur/R_pasteur_phd/scripts/Demo_RMarkdown_April_2021")
# Or, programmatically (only works upon "Source")
# (https://stackoverflow.com/a/16046056/1878788):
setwd(dirname(sys.frame(1)$ofile))

# Load table
mi <- read.csv("mi.csv", row.names = 1)

# Check the table
str(mi)

# Successive dashes enables section folding in RStudio
# My first part --------------------------------------

############## Sex
# Describe
table(mi$Sex)
table(mi$Sex, exclude = NULL)

# Proportion
prop.table(table(mi$Sex))

# Percentage
prop.table(table(mi$Sex)) * 100

# Plot
plot_sex <- barplot(table(mi$Sex), col = "red")
plot_sex



# Plot using ggplot
# progressively constructing the graph in a ggplot object
# Specify the data source to use
ggplot_sex <- ggplot(data = mi, aes(x = Sex))
# Build a bar plot
ggplot_sex <- ggplot_sex + geom_bar(
   stat = "count", fill = "lightblue", col = "black")
# Set the theme
ggplot_sex <- ggplot_sex + theme_classic()
# To display the resulting graph in the current graphical device
ggplot_sex


############## Age
# Describe
summary(mi$Age)
mean(mi$Age, rm.na = TRUE)

# Class of variable Age
class(mi$Age)

# Recode the age
# It may be useful to either remove or replace NAs
# (The mean is just used as an example replacement,
# this may not be a good idea in practice.)
mi$Age_categorical <- ifelse(
   is.na(mi$Age), mean(mi$Age), mi$Age)

mi$Age_categorical <- ifelse(
   mi$Age<40, "under 40", "equal or over 40")

table(mi$Age_categorical)


# You can also use cut to create factors with full control
mi$Agef <- cut(
   mi$Age,
   breaks = c(min(mi$Age), 40, max(mi$Age)),
   labels = c("under 40", "equal or over 40"),
   right = FALSE,
   include.lowest = TRUE)


table(mi$Agef)

# Class of variables
class(mi$Agef)
class(mi$Age_categorical)

# Change Age_categorical into a factor
# mi$Age_categorical<-as.factor(mi$Age_categorical)
# Or, allowing more control on the levels
mi$Age_categorical <- factor(
   mi$Age_categorical,
   levels = c("under 40", "equal or over 40"))
class(mi$Age_categorical)

# It is also possible to convert the other way round
# Change Agef into a character
mi$Agef <- as.character(mi$Agef)
class(mi$Agef)

# My second part -------------------------------

# Save this data frame with the new variable Age_categorical
# Several output formats are possible.
write.csv(mi, "mi_new.csv")
write.xlsx(mi, "mi_new.xlsx")


# Save a plot
# Open a jpeg file as graphical device
jpeg(file = "plot_sex.jpeg")

barplot(table(mi$Sex), col = "lightblue")

# Close the jpeg file
# (saves the file and restores the default graphical device)
dev.off()


# Save a ggpplot
# (device opening and closing is automatic here)
ggsave(plot = ggplot_sex, file = "ggplot_sex.jpg")



# My third part -------------------------------
###### See variables
# As a vector
names(mi)
# As a matrix
matrix(colnames(mi), ncol = 1)



####### Automatic description using CreateTableOne 
###### Be careful with the format of variables,
###### the class, the missing values
description <- CreateTableOne(
   data = mi,
   vars = c("Age",  "Age_categorical",
            "BMI",  "Smoking", "Employed", "Education"))


# Description by sex
description_by_sex <- CreateTableOne(
   data = mi,
   vars = c("Age", "Age_categorical",
            "BMI", "Smoking", "Employed", "Education"),
   strata = "Sex",
   test = FALSE)  # avoid "black box" tests, do your own with full control




# Change the format of tables to be printed in a word document
description <- as.data.frame(print(description))
description_by_sex <- as.data.frame(print(description_by_sex))

# Add the variable name as a new column
description <- cbind(row.names(description), description)
description_by_sex <- cbind(
   row.names(description_by_sex),
   description_by_sex)


# Export as a word document ------------------------------
# Create a word document
my_doc <- read_docx()
# Not sure this is useful, test without if you want
styles_info(my_doc)

### What I want inside my word document
### body_add_par : add text
### body_add_table : add table
### body_add_gg : add ggplot


# Add a title to my document
my_doc <- body_add_par(my_doc, "My title", style = "centered")

# Add title to my ggplot
my_doc <- body_add_par(my_doc, "ggplot sex")
# Add a ggplot
my_doc <- body_add_gg(my_doc, ggplot_sex)

# Add tables
my_doc <- body_add_par(my_doc, "Table 2: global description")
my_doc <- body_add_table(my_doc, description)
my_doc <- body_add_par(my_doc, "Table 3: description by sex")
my_doc <- body_add_table(my_doc, description_by_sex)

# Save the word document
print(
   my_doc,
   target = "my_result_in_a_word.docx")
